@@ -82,12 +82,6 @@ class Risk(NetBoxModel):
     )
     comments = models.TextField(blank=True)
 
-    tags = models.CharField(
-        max_length=250,
-        unique=False,
-        related_name='risk_tag'
-    )
-
     class Meta:
         ordering = ['name']
 
@@ -131,7 +125,7 @@ class RiskRelation(NetBoxModel):
         blank=True,
     )
 
-    tags = models.CharField(
+    models.CharField(
         max_length=250,
         unique=False,
         related_name='risk_relation_tag'
